@@ -51,6 +51,7 @@ from .type_defs import (
     DomainEndpointOptionsTypeDef,
     DomainInformationContainerTypeDef,
     EBSOptionsTypeDef,
+    EmptyResponseMetadataTypeDef,
     EncryptionAtRestOptionsTypeDef,
     FilterTypeDef,
     GetCompatibleVersionsResponseTypeDef,
@@ -137,7 +138,7 @@ class OpenSearchServiceClient(BaseClient):
         [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_opensearch/client/#accept_inbound_connection)
         """
 
-    def add_tags(self, *, ARN: str, TagList: Sequence["TagTypeDef"]) -> None:
+    def add_tags(self, *, ARN: str, TagList: Sequence[TagTypeDef]) -> EmptyResponseMetadataTypeDef:
         """
         Attaches tags to an existing domain.
 
@@ -179,20 +180,20 @@ class OpenSearchServiceClient(BaseClient):
         *,
         DomainName: str,
         EngineVersion: str = ...,
-        ClusterConfig: "ClusterConfigTypeDef" = ...,
-        EBSOptions: "EBSOptionsTypeDef" = ...,
+        ClusterConfig: ClusterConfigTypeDef = ...,
+        EBSOptions: EBSOptionsTypeDef = ...,
         AccessPolicies: str = ...,
-        SnapshotOptions: "SnapshotOptionsTypeDef" = ...,
-        VPCOptions: "VPCOptionsTypeDef" = ...,
-        CognitoOptions: "CognitoOptionsTypeDef" = ...,
-        EncryptionAtRestOptions: "EncryptionAtRestOptionsTypeDef" = ...,
-        NodeToNodeEncryptionOptions: "NodeToNodeEncryptionOptionsTypeDef" = ...,
+        SnapshotOptions: SnapshotOptionsTypeDef = ...,
+        VPCOptions: VPCOptionsTypeDef = ...,
+        CognitoOptions: CognitoOptionsTypeDef = ...,
+        EncryptionAtRestOptions: EncryptionAtRestOptionsTypeDef = ...,
+        NodeToNodeEncryptionOptions: NodeToNodeEncryptionOptionsTypeDef = ...,
         AdvancedOptions: Mapping[str, str] = ...,
-        LogPublishingOptions: Mapping[LogTypeType, "LogPublishingOptionTypeDef"] = ...,
-        DomainEndpointOptions: "DomainEndpointOptionsTypeDef" = ...,
-        AdvancedSecurityOptions: "AdvancedSecurityOptionsInputTypeDef" = ...,
-        TagList: Sequence["TagTypeDef"] = ...,
-        AutoTuneOptions: "AutoTuneOptionsInputTypeDef" = ...
+        LogPublishingOptions: Mapping[LogTypeType, LogPublishingOptionTypeDef] = ...,
+        DomainEndpointOptions: DomainEndpointOptionsTypeDef = ...,
+        AdvancedSecurityOptions: AdvancedSecurityOptionsInputTypeDef = ...,
+        TagList: Sequence[TagTypeDef] = ...,
+        AutoTuneOptions: AutoTuneOptionsInputTypeDef = ...
     ) -> CreateDomainResponseTypeDef:
         """
         Creates a new Amazon OpenSearch Service domain.
@@ -204,8 +205,8 @@ class OpenSearchServiceClient(BaseClient):
     def create_outbound_connection(
         self,
         *,
-        LocalDomainInfo: "DomainInformationContainerTypeDef",
-        RemoteDomainInfo: "DomainInformationContainerTypeDef",
+        LocalDomainInfo: DomainInformationContainerTypeDef,
+        RemoteDomainInfo: DomainInformationContainerTypeDef,
         ConnectionAlias: str
     ) -> CreateOutboundConnectionResponseTypeDef:
         """
@@ -221,7 +222,7 @@ class OpenSearchServiceClient(BaseClient):
         *,
         PackageName: str,
         PackageType: Literal["TXT-DICTIONARY"],
-        PackageSource: "PackageSourceTypeDef",
+        PackageSource: PackageSourceTypeDef,
         PackageDescription: str = ...
     ) -> CreatePackageResponseTypeDef:
         """
@@ -319,11 +320,7 @@ class OpenSearchServiceClient(BaseClient):
         """
 
     def describe_inbound_connections(
-        self,
-        *,
-        Filters: Sequence["FilterTypeDef"] = ...,
-        MaxResults: int = ...,
-        NextToken: str = ...
+        self, *, Filters: Sequence[FilterTypeDef] = ..., MaxResults: int = ..., NextToken: str = ...
     ) -> DescribeInboundConnectionsResponseTypeDef:
         """
         Lists all the inbound cross-cluster connections for a remote domain.
@@ -348,11 +345,7 @@ class OpenSearchServiceClient(BaseClient):
         """
 
     def describe_outbound_connections(
-        self,
-        *,
-        Filters: Sequence["FilterTypeDef"] = ...,
-        MaxResults: int = ...,
-        NextToken: str = ...
+        self, *, Filters: Sequence[FilterTypeDef] = ..., MaxResults: int = ..., NextToken: str = ...
     ) -> DescribeOutboundConnectionsResponseTypeDef:
         """
         Lists all the outbound cross-cluster connections for a local domain.
@@ -364,7 +357,7 @@ class OpenSearchServiceClient(BaseClient):
     def describe_packages(
         self,
         *,
-        Filters: Sequence["DescribePackagesFilterTypeDef"] = ...,
+        Filters: Sequence[DescribePackagesFilterTypeDef] = ...,
         MaxResults: int = ...,
         NextToken: str = ...
     ) -> DescribePackagesResponseTypeDef:
@@ -544,7 +537,7 @@ class OpenSearchServiceClient(BaseClient):
         [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_opensearch/client/#reject_inbound_connection)
         """
 
-    def remove_tags(self, *, ARN: str, TagKeys: Sequence[str]) -> None:
+    def remove_tags(self, *, ARN: str, TagKeys: Sequence[str]) -> EmptyResponseMetadataTypeDef:
         """
         Removes the specified set of tags from the given domain.
 
@@ -566,19 +559,19 @@ class OpenSearchServiceClient(BaseClient):
         self,
         *,
         DomainName: str,
-        ClusterConfig: "ClusterConfigTypeDef" = ...,
-        EBSOptions: "EBSOptionsTypeDef" = ...,
-        SnapshotOptions: "SnapshotOptionsTypeDef" = ...,
-        VPCOptions: "VPCOptionsTypeDef" = ...,
-        CognitoOptions: "CognitoOptionsTypeDef" = ...,
+        ClusterConfig: ClusterConfigTypeDef = ...,
+        EBSOptions: EBSOptionsTypeDef = ...,
+        SnapshotOptions: SnapshotOptionsTypeDef = ...,
+        VPCOptions: VPCOptionsTypeDef = ...,
+        CognitoOptions: CognitoOptionsTypeDef = ...,
         AdvancedOptions: Mapping[str, str] = ...,
         AccessPolicies: str = ...,
-        LogPublishingOptions: Mapping[LogTypeType, "LogPublishingOptionTypeDef"] = ...,
-        EncryptionAtRestOptions: "EncryptionAtRestOptionsTypeDef" = ...,
-        DomainEndpointOptions: "DomainEndpointOptionsTypeDef" = ...,
-        NodeToNodeEncryptionOptions: "NodeToNodeEncryptionOptionsTypeDef" = ...,
-        AdvancedSecurityOptions: "AdvancedSecurityOptionsInputTypeDef" = ...,
-        AutoTuneOptions: "AutoTuneOptionsTypeDef" = ...,
+        LogPublishingOptions: Mapping[LogTypeType, LogPublishingOptionTypeDef] = ...,
+        EncryptionAtRestOptions: EncryptionAtRestOptionsTypeDef = ...,
+        DomainEndpointOptions: DomainEndpointOptionsTypeDef = ...,
+        NodeToNodeEncryptionOptions: NodeToNodeEncryptionOptionsTypeDef = ...,
+        AdvancedSecurityOptions: AdvancedSecurityOptionsInputTypeDef = ...,
+        AutoTuneOptions: AutoTuneOptionsTypeDef = ...,
         DryRun: bool = ...
     ) -> UpdateDomainConfigResponseTypeDef:
         """
@@ -593,7 +586,7 @@ class OpenSearchServiceClient(BaseClient):
         self,
         *,
         PackageID: str,
-        PackageSource: "PackageSourceTypeDef",
+        PackageSource: PackageSourceTypeDef,
         PackageDescription: str = ...,
         CommitMessage: str = ...
     ) -> UpdatePackageResponseTypeDef:
